@@ -3,8 +3,9 @@ import json
 import multiprocessing as mp
 from collections import Counter, defaultdict
 from pathlib import Path
-from typing import Any, Dict, Generator, List, Optional, Set, Tuple, Union
+from typing import Any, Dict, Generator, Iterator, List, Optional, Set, Tuple, Union
 
+import darwin.datatypes as dt
 import numpy as np
 from darwin.exceptions import NotFound
 from darwin.importer.formats.darwin import parse_file
@@ -18,7 +19,7 @@ from rich.live import Live
 from rich.progress import ProgressBar, track
 
 
-def get_release_path(dataset_path: Path, release_name: Optional[str] = None):
+def get_release_path(dataset_path: Path, release_name: Optional[str] = None) -> Path:
     """
     Given a dataset path and a release name, returns the path to the release
 
@@ -39,7 +40,7 @@ def get_release_path(dataset_path: Path, release_name: Optional[str] = None):
     if not release_name:
         release_name = "latest"
 
-    release_path = dataset_path / "releases" / release_name
+    release_path: Path = dataset_path / "releases" / release_name
     if not release_path.exists():
         raise NotFound(
             f"Local copy of release {release_name} not found: "
@@ -299,7 +300,7 @@ def get_annotations(
     assert dataset_path is not None
     dataset_path = Path(dataset_path)
 
-    release_path = get_release_path(dataset_path, release_name)
+    release_path: Path = get_release_path(dataset_path, release_name)
 
     annotations_dir = release_path / "annotations"
     assert annotations_dir.exists()
@@ -324,9 +325,13 @@ def get_annotations(
             split_file = f"{split_type}_{partition}.txt"
         elif split_type == "stratified":
             split_file = f"{split_type}_{annotation_type}_{partition}.txt"
-        split_path = release_path / "lists" / split / split_file
+        else:
+            raise ValueError(f"Invalid split_type ({split_type})")
+
+        split_path: Path = release_path / "lists" / str(split) / split_file
+
         if split_path.is_file():
-            stems = (e.strip() for e in split_path.open())
+            stems: Iterator[str] = (e.rstrip("\n\r") for e in split_path.open())
         else:
             raise FileNotFoundError(
                 f"Could not find a dataset partition. ",
@@ -494,17 +499,17 @@ def compute_distributions(
 
     for partition in partitions:
         for annotation_type in annotation_types:
-            split_file = split_path / f"stratified_{annotation_type}_{partition}.txt"
-            stems = [e.strip() for e in split_file.open()]
+            split_file: Path = split_path / f"stratified_{annotation_type}_{partition}.txt"
+            stems: List[str] = [e.rstrip("\n\r") for e in split_file.open()]
 
             for stem in stems:
-                annotation_path = annotations_dir / f"{stem}.json"
-                annotation_file = parse_file(annotation_path)
+                annotation_path: Path = annotations_dir / f"{stem}.json"
+                annotation_file: Optional[dt.AnnotationFile] = parse_file(annotation_path)
 
                 if annotation_file is None:
                     continue
 
-                annotation_class_names = [
+                annotation_class_names: List[str] = [
                     annotation.annotation_class.name for annotation in annotation_file.annotations
                 ]
 
